@@ -12,7 +12,7 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.2.2'
+VERSION = '0.3.0'
 
 default_backliftURL = 'https://www.backlift.com/'
 backlift_configfile = '.backlift'
@@ -124,9 +124,12 @@ def collectFiles(path, skip_hidden):
     files = {}
 
     for filepath in filelist:
-        filekey = filepath.replace(rootpath, '', 1).strip('/')
-        files[filekey] = (filekey, open(filepath, 'rb'))
-        print "Adding %s" % filekey
+        try:
+            filekey = filepath.replace(rootpath, '', 1).strip('/')
+            files[filekey] = (filekey, open(filepath, 'rb'))
+            print "Adding %s" % filekey
+        except OSError:
+            continue
 
     return files, configfile
 
@@ -134,8 +137,14 @@ def collectFiles(path, skip_hidden):
 def scanFiles(path, skip_hidden):
     rootpath = os.path.normpath(os.path.abspath(path))
     filelist, configfile = listFiles(rootpath, skip_hidden)
-    return dict ([(f, os.stat(f).st_mtime) for f in filelist]),\
-           configfile
+    times = {}
+    for f in filelist:
+        try:
+            times[f] = os.stat(f).st_mtime
+        except OSError:
+            continue
+    return times, configfile
+
 
 
 def get_id(configfile):
@@ -397,13 +406,15 @@ def watch(path, skip_hidden):
             
             added = [f for f in after if not f in before]
             removed = [f for f in before if not f in after]
-            modified = [f for f in after if after[f] != before[f]]
+            modified = [f for f in after if \
+                (f in before and f in after and after[f] != before[f])]
             
             if added: print "Added: ", ", ".join (added)
             if removed: print "Removed: ", ", ".join (removed)
             if modified: print "Modified: ", ", ".join (modified)
             
             if added or removed or modified:    
+                # import pdb; pdb.set_trace()
                 files, configfile = collectFiles(path, skip_hidden)        
                 upload_files(id, files, api_key)
     
